Complexity, Fractals, and Entropy
-----------------------------------

Main
^^^^^^^^^^^^^^^^
*complexity()*
"""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity


Parameters Choice
^^^^^^^^^^^^^^^^^^
*complexity_delay()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_delay

*complexity_dimension()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_dimension

*complexity_tolerance()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_tolerance

*complexity_k()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_k


Fractal Dimension
^^^^^^^^^^^^^^^^^
*fractal_katz()*
"""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_katz

*fractal_linelength()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_linelength

*fractal_petrosian()*
"""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_petrosian

*fractal_sevcik()*
""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_sevcik

*fractal_nld()*
""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_nld

*fractal_psdslope()*
""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_psdslope

*fractal_higuchi()*
""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_higuchi

*fractal_density()*
""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_density

*fractal_hurst()*
"""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_hurst

*fractal_correlation()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_correlation

*fractal_dfa()*
""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_dfa

*fractal_tmf()*
""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_tmf

Entropy
^^^^^^^^^^^^^^^^^
*entropy_shannon()*
"""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_shannon

*entropy_maximum()*
"""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_maximum

*entropy_differential()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_differential

*entropy_power()*
"""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_power

*entropy_tsallis()*
"""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_tsallis

*entropy_renyi()*
"""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_renyi

*entropy_cumulativeresidual()*
"""""""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_cumulativeresidual

*entropy_rate()*
"""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_rate

*entropy_svd()*
"""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_svd

*entropy_kl()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_kl

*entropy_spectral()*
""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_spectral

*entropy_phase()*
""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_phase

*entropy_grid()*
""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_grid

*entropy_attention()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_attention

*entropy_increment()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_increment

*entropy_slope()*
"""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_slope

*entropy_symbolicdynamic()*
"""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_symbolicdynamic

*entropy_dispersion()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_dispersion

*entropy_ofentropy()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_ofentropy

*entropy_approximate()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_approximate

*entropy_sample()*
""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_sample

*entropy_permutation()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_permutation

*entropy_bubble()*
""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_bubble

*entropy_range()*
""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_range

*entropy_fuzzy()*
""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_fuzzy

*entropy_multiscale()*
""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_multiscale

*entropy_hierarchical()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_hierarchical


Other indices
^^^^^^^^^^^^^^^^^
*fisher_information()*
""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fisher_information

*fishershannon_information()*
""""""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fishershannon_information

*mutual_information()*
""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.mutual_information

*complexity_hjorth()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_hjorth

*complexity_decorrelation()*
"""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_decorrelation

*complexity_lempelziv()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_lempelziv

*complexity_relativeroughness()*
""""""""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_relativeroughness

*complexity_lyapunov()*
"""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_lyapunov

*complexity_rqa()*
""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_rqa


Utilities
^^^^^^^^^^^^^^^^^^^^^^^^^^^^
*fractal_mandelbrot()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.fractal_mandelbrot

*complexity_simulate()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_simulate

*complexity_embedding()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_embedding

*complexity_attractor()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_attractor

*complexity_symbolize*
""""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_symbolize

*complexity_coarsegraining()*
""""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_coarsegraining

*complexity_ordinalpatterns()*
""""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.complexity_ordinalpatterns

*recurrence_matrix()*
""""""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.recurrence_matrix


Joint/Multivariate
^^^^^^^^^^^^^^^^^^^^^^
*entropy_shannon_joint()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.complexity.entropy_shannon_joint


.. *Other*
.. ^^^^^^^^^

.. .. automodule:: neurokit2.complexity
..    :members:
..    :exclude-members: complexity, complexity_delay, complexity_dimension, complexity_tolerance, complexity_k, fractal_katz, fractal_petrosian, fractal_sevcik, fractal_nld, fractal_psdslope, fractal_higuchi, fractal_correlation, entropy_shannon, entropy_maximum, entropy_differential, entropy_tsallis, entropy_renyi, entropy_cumulativeresidual, entropy_svd, entropy_spectral, entropy_phase, entropy_grid, entropy_attention, entropy_increment, entropy_slope, entropy_symbolicdynamic, entropy_dispersion, entropy_ofentropy, entropy_approximate, entropy_sample, entropy_permutation, entropy_bubble, entropy_range, entropy_fuzzy, entropy_multiscale, entropy_hierarchical, fisher_information, complexity_hjorth, complexity_lempelziv, complexity_relativeroughness, fractal_hurst, complexity_lyapunov, complexity_rqa, fractal_mandelbrot, complexity_simulate, complexity_attractor, complexity_symbolize, complexity_coarsegraining, complexity_ordinalpatterns, recurrence_matrix, entropy_shannon_joint, entropy_rate